#ifndef NT2_INCLUDE_FUNCTIONS_ASECH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ASECH_HPP_INCLUDED

#include <nt2/hyperbolic/include/functions/asech.hpp>

#endif
